@@ -6,6 +6,7 @@ import { Section } from "../Section";
 import { Group } from "../Group";
 import { Page } from "../Page";
 import { ScrollArea } from "../../../ScrollArea";
+import { useStore } from "../../Menu";
 
 import {
     NavigationType,
@@ -19,7 +20,7 @@ import "./MenuContent.css";
 
 type MenuContentProps = {
     content: NavigationType;
-    onPageChange: (url: string) => void;
+    groupsInitiallyCollapsed?: boolean;
 };
 
 const searchTitle = (title: string, query: string): boolean => {
@@ -112,7 +113,8 @@ const recursivelyFilterNavigation = (
 const makeNavigation = (
     navigation: NavigationType,
     filtered: boolean,
-    onPageChange: (url: string) => void
+    initiallyCollapsed: boolean,
+    firstPageHref: string
 ): JSX.Element => {
     const recursivelyMakeNavigation = (
         items: NavigationItemType[],
@@ -151,6 +153,7 @@ const makeNavigation = (
                                     iconAtParentLevel ||
                                     false
                                 }
+                                initiallyCollapsed={initiallyCollapsed}
                             >
                                 {recursivelyMakeNavigation(
                                     (item as GroupType).content,
@@ -164,15 +167,28 @@ const makeNavigation = (
                             <Page
                                 key={item.id}
                                 level={level}
+                                firstPage={
+                                    (item as PageType).href === firstPageHref
+                                }
                                 applyIconIndentation={
                                     atLeastOneIconUsed ||
                                     iconAtParentLevel ||
                                     false
                                 }
                                 {...(item as PageType)}
-                                onClick={() =>
-                                    onPageChange((item as PageType).href)
-                                }
+                                onClick={() => {
+                                    window.history.pushState(
+                                        {},
+                                        "",
+                                        (item as PageType).href
+                                    );
+                                    window.dispatchEvent(
+                                        new CustomEvent(
+                                            "_dashprivate_pushstate"
+                                        )
+                                    );
+                                    window.scrollTo(0, 0);
+                                }}
                             />
                         );
                     } else {
@@ -189,6 +205,8 @@ export const MenuContent: React.FC<MenuContentProps> = (props) => {
     const [filter, setFilter] = React.useState<string>("");
     const [content, setContent] = React.useState<NavigationType>(props.content);
 
+    const store = useStore();
+
     React.useEffect(() => {
         setContent(recursivelyFilterNavigation(props.content, filter));
     }, [filter, props.content]);
@@ -198,13 +216,18 @@ export const MenuContent: React.FC<MenuContentProps> = (props) => {
             <div className="Menu__FilterInputWrapper">
                 <FilterInput filter={filter} onFilterChange={setFilter} />
             </div>
-            <ScrollArea>
+            <ScrollArea noScrollbarPadding={true}>
                 {content.length === 0 ? (
                     <div className="Menu__NoResults">
                         No pages matching the query...
                     </div>
                 ) : (
-                    makeNavigation(content, filter !== "", props.onPageChange)
+                    makeNavigation(
+                        content,
+                        filter !== "",
+                        props.groupsInitiallyCollapsed || false,
+                        store.firstPageHref
+                    )
                 )}
             </ScrollArea>
         </div>
@@ -213,5 +236,5 @@ export const MenuContent: React.FC<MenuContentProps> = (props) => {
 
 MenuContent.propTypes = {
     content: PropTypes.any.isRequired,
-    onPageChange: PropTypes.func.isRequired,
+    groupsInitiallyCollapsed: PropTypes.bool,
 };
