@@ -11,10 +11,14 @@ import dash as _dash
 from ._imports_ import *
 from ._imports_ import __all__
 
-from .graph import Graph
-from .flexbox import FlexBox
+from .wrapped_components import *
+from .wrapped_components import __all__ as wrapped_components
 
-__all__ += ["Graph", "FlexBox"]
+from .WebvizPluginPlaceholderWrapper import (
+    WebvizPluginPlaceholderWrapper as WebvizPluginPlaceholder,
+)
+
+__all__ += wrapped_components
 
 try:
     __version__ = get_distribution(__name__).version
@@ -33,7 +37,7 @@ if not hasattr(_dash, "development"):
 
 _basepath = _os.path.dirname(__file__)
 _filepath = _os.path.abspath(_os.path.join(_basepath, "package.json"))
-with open(_filepath) as f:
+with open(_filepath, encoding="utf8") as f:
     package = json.load(f)
 
 package_name = (
